Release Notes
=============

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <http://keepachangelog.com/>`_ and
this project adheres to `Semantic Versioning <http://semver.org/>`_.


0.5_ - 2016/10/22
-----------------

Added
:::::

* Bump support for Django up to 1.10, add it to the test suite.

0.4_ - 2016/08/06
-----------------

Added
:::::

* Allow ``build`` to bypass full clean. Allows creation of invalid data.

0.3 - 2016/05/10
-----------------

Stable testing release.

.. _0.5: https://github.com/jamescooke/factory_djoy/compare/v0.4...v0.5
.. _0.4: https://github.com/jamescooke/factory_djoy/compare/v0.3...v0.4
